Security Advisories (5)
CVE-2006-4484 (2008-10-01)

Buffer overflow in the LWZReadByte_ function in the GD extension in allows remote attackers to have an unknown impact via a GIF file with input_code_size greater than MAX_LWZ_BITS, which triggers an overflow when initializing the table array.

CVE-2007-4769 (2008-01-09)

The regular expression parser in TCL before 8.4.17, as used in PostgreSQL 8.2 before 8.2.6, 8.1 before 8.1.11, 8.0 before 8.0.15, and 7.4 before 7.4.19, allows remote authenticated users to cause a denial of service (backend crash) via an out-of-bounds backref number.

CVE-2003-0107 (2003-03-07)

Buffer overflow in the gzprintf function in zlib 1.1.4, when zlib is compiled without vsnprintf or when long inputs are truncated using vsnprintf, allows attackers to cause a denial of service or possibly execute arbitrary code.

CVE-2007-4772 (2008-01-09)

The regular expression parser in TCL before 8.4.17, as used in PostgreSQL 8.2 before 8.2.6, 8.1 before 8.1.11, 8.0 before 8.0.15, and 7.4 before 7.4.19, allows context-dependent attackers to cause a denial of service (infinite loop) via a crafted regular expression.

CVE-2007-6067 (2008-01-09)

Algorithmic complexity vulnerability in the regular expression parser in TCL before 8.4.17, as used in PostgreSQL 8.2 before 8.2.6, 8.1 before 8.1.11, 8.0 before 8.0.15, and 7.4 before 7.4.19, allows remote authenticated users to cause a denial of service (memory consumption) via a crafted "complex" regular expression with doubly-nested states.

NAME

Tk::Animation - Display sequence of Tk::Photo images

SYNOPSIS

use Tk::Animation
my $img = $widget->Animation('-format' => 'gif', -file => 'somefile.gif');

$img->add_frame(@images);

$img->start_animation($period);
$img->stop_animation;

DESCRIPTION

In the simple case when Animation is passed a GIF89 style GIF with multiple 'frames', it will build an internal array of Photo images.

The add_frame method adds images to the sequence. It is provided to allow animations to be constructed from separate images. All images must be Photos and should all be the same size.

start_animation($period) then initiates a repeat with specified $period to sequence through these images. As for raw repeat $period is in milli-seconds, for a 50Hz monitor it should be at least 20mS.

stop_animation cancels the repeat and resets the image to the first image in the sequence.

BUGS

The 'period' should probably be a property of the Animation object rather than specified at 'start' time. It may even be embedded in the GIF.